==> json-joy-7.11.0.tgz: package/esm/json-block/Block.js <==
import { BehaviorSubject, of } from 'rxjs';
import { switchMap } from 'rxjs/operators';
export class BasicBlock {
    model;
    version$;
    constructor(version, model) {
        this.model = model;
        this.version$ = new BehaviorSubject(version);
    }
    fork() {
        return new BasicBlock(this.version$.getValue(), this.model.fork());
    }
    data$() {
        return this.version$.pipe(switchMap(() => of(this.model.getData())));
    }
    getData() {
        return this.model.getData();
    }
    apply(patch) {
        this.model.apply(patch);
        this.version$.next(this.version$.getValue() + 1);
    }
}
export class Branch {
    base$;
    head$;
    patches;
    merging = 0;
    constructor(base) {
        this.base$ = new BehaviorSubject(base);
        this.patches = [];
        this.head$ = new BehaviorSubject(base.fork());
    }
    async merge(opts) {
        try {
            const base = this.base$.getValue();
            const baseVersion = base.version$.getValue();
            const batch = [...this.patches];
            this.merging = batch.length;
            const res = await opts.merge(baseVersion, batch);
        }
        catch (error) {
            this.merging = 0;
        }
    }
    commit(patch) {
        this.patches.push(patch);
        this.head$.getValue().apply(patch);
    }
    rebase(patches) {
        const base = this.base$.getValue();
        for (const patch of patches)
            base.apply(patch);
        const head = base.fork();
        for (const patch of this.patches)
            head.apply(patch);
        this.head$.next(head);
    }
    reset(base) {
        this.base$.next(base);
        const patches = this.patches;
        this.patches = [];
        this.head$.next(base.fork());
        return patches;
    }
}

==> json-joy-7.14.0.tgz: package/esm/json-block/Block.js <==
import { BehaviorSubject, of } from 'rxjs';
import { switchMap } from 'rxjs/operators';
export class BasicBlock {
    model;
    v$;
    constructor(version, model) {
        this.model = model;
        this.v$ = new BehaviorSubject(version);
    }
    fork() {
        return new BasicBlock(this.v$.getValue(), this.model.fork());
    }
    data$() {
        return this.v$.pipe(switchMap(() => of(this.model.getData())));
    }
    getData() {
        return this.model.getData();
    }
    apply(patch) {
        this.model.apply(patch);
        this.v$.next(this.v$.getValue() + 1);
    }
}
export class Branch {
    base$;
    head$;
    patches;
    merging = 0;
    constructor(base) {
        this.base$ = new BehaviorSubject(base);
        this.patches = [];
        this.head$ = new BehaviorSubject(base.fork());
    }
    async merge(opts) {
        try {
            const base = this.base$.getValue();
            const baseVersion = base.v$.getValue();
            const batch = [...this.patches];
            this.merging = batch.length;
            const res = await opts.merge(baseVersion, batch);
        }
        catch (error) {
            this.merging = 0;
        }
    }
    commit(patch) {
        this.patches.push(patch);
        this.head$.getValue().apply(patch);
    }
    rebase(patches) {
        const base = this.base$.getValue();
        for (const patch of patches)
            base.apply(patch);
        const head = base.fork();
        for (const patch of this.patches)
            head.apply(patch);
        this.head$.next(head);
    }
    reset(base) {
        this.base$.next(base);
        const patches = this.patches;
        this.patches = [];
        this.head$.next(base.fork());
        return patches;
    }
}
